<?php

$fileDir = dirname(__FILE__);
if (file_exists($fileDir . '/301config.php'))
{
	include($fileDir . '/301config.php');
}

require($fileDir . '/src/XF.php');

XF::start($fileDir);

$app = XF::setupApp('XF\Pub\App');
$router = $app->router('public');
$request = $app->request();

$log = new \XF\Import\Log($app->db(), defined('IMPORT_LOG_TABLE') ? IMPORT_LOG_TABLE : 'xf_import_log');

$input = $request->filter(array(
	'p' => 'uint',
	'showtopic' => 'uint',
	'showforum' => 'uint',
	'showuser' => 'uint',
	'attach_id' => 'uint',

	'app' => 'str',
	'module' => 'str',
	'section' => 'str',
));

if ($input['p'])
{
	$input['type'] = '__p__';
	$input['id'] = $input['p'];
}
else if ($input['showtopic'])
{
	$input['type'] = 'topic';
	$input['id'] = $input['showtopic'];
}
else if ($input['showforum'])
{
	$input['type'] = 'forum';
	$input['id'] = $input['showforum'];
}
else if ($input['showuser'])
{
	$input['type'] = 'user';
	$input['id'] = $input['showuser'];
}
else if ($input['attach_id'] && $input['app'] == 'core' && $input['module'] == 'attach' &&  $input['section'] = 'attach')
{
	$input['type'] = 'attachment';
	$input['id'] = $input['attach_id'];
}
else if (!preg_match('#(?P<type>__p__)(?P<id>\d+)#s', $_SERVER['REQUEST_URI'], $input)) // posts
{
	preg_match('#/(?P<type>topic|forum|user)/(?P<id>\d+)#s', $_SERVER['REQUEST_URI'], $input); // threads, forums, users
}

$target = false;

if (!empty($input['id']))
{
	switch ($input['type'])
	{
		case 'forum':
		{
			$newId = $log->lookupId('node', $input['id']);
			if ($newId)
			{
				$target = $router->buildLink('canonical:forums', ['node_id' => $newId]);
			}
			break;
		}

		case 'topic': // threads
		{
			$newId = $log->lookupId('thread', $input['id']);
			if ($newId)
			{
				$target = $router->buildLink('canonical:threads', ['thread_id' => $newId]);
			}
			break;
		}

		case '__p__': // posts
		{
			$newId = $log->lookupId('post', $input['id']);
			if ($newId)
			{
				$target = $router->buildLink('canonical:posts', ['post_id' => $newId]);
			}
			break;
		}

		case 'attachment':
		{
			$newId = $log->lookupId('attachment', $input['id']);
			if ($newId)
			{
				$target = $router->buildLink('canonical:attachments', ['attachment_id' => $newId]);
			}
			break;
		}

		case 'user':
		{
			$newId = $log->lookupId('user', $input['id']);
			if ($newId)
			{
				$target = $router->buildLink('canonical:members', ['user_id' => $newId]);
			}
			break;
		}
	}
}

if (!$target)
{
	$target = $router->buildLink('canonical:index');
}

$response = $app->response();
$response->redirect($request->convertToAbsoluteUri($target), 301);
$response->send($request);